<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests\BannerRequest;
use Backpack\CRUD\app\Http\Controllers\CrudController;
use Backpack\CRUD\app\Library\CrudPanel\CrudPanelFacade as CRUD;

/**
 * Class BannerCrudController
 * @package App\Http\Controllers\Admin
 * @property-read \Backpack\CRUD\app\Library\CrudPanel\CrudPanel $crud
 */
class BannerCrudController extends CrudController
{
    use \Backpack\CRUD\app\Http\Controllers\Operations\ListOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\CreateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\UpdateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\DeleteOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\ShowOperation;

    /**
     * Configure the CrudPanel object. Apply settings to all operations.
     *
     * @return void
     */
    public function setup()
    {
        CRUD::setModel(\App\Models\Banner::class);
        CRUD::setRoute(config('backpack.base.route_prefix') . '/banner');
        CRUD::setEntityNameStrings('banner', 'banners');
    }

    /**
     * Define what happens when the List operation is loaded.
     *
     * @see  https://backpackforlaravel.com/docs/crud-operation-list-entries
     * @return void
     */
    protected function setupListOperation()
    {
        CRUD::setOperationSetting('lineButtonsAsDropdown', true);

        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();

        $this->crud->addColumn([
            'name'=>'top_text',
            'label'=>'Top Text'
        ]);
        $this->crud->addColumn([
            'name'=>'main_text',
            'label'=>'Main Text'
        ]);

        $this->crud->addColumn([
            'name' => 'image',
            'label' => 'Image',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
    }

    /**
     * Define what happens when the Create operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-create
     * @return void
     */
    protected function setupCreateOperation()
    {
        CRUD::setValidation(BannerRequest::class);
        CRUD::setFromDb(); // set fields from db columns.

        CRUD::field('top_text')->type('text')->label('Top Text (EN)')->wrapper(['class' => 'col-md-6']);
        CRUD::field('top_text_arabic')->type('text')->label('Top Text (AR)')->wrapper(['class' => 'col-md-6']);

        CRUD::field('image')->type('upload')
        ->label('Image ( 1028x724 )')
        ->withFiles([
            'disk' => 'public',
            'path' => 'banners',
        ])->wrapper(['class' => 'col-md-6']);
        CRUD::field('main_text')->type('text')->label('Title Text (EN)')->wrapper(['class' => 'col-md-6']);
        CRUD::field('main_text_arabic')->type('text')->label('Title Text (AR)')->wrapper(['class' => 'col-md-6']);

        CRUD::field('description')->type('text')->label('Description (EN)');
        CRUD::field('description_arabic')->type('text')->label('Description (AR)');

        CRUD::field('status')
        ->type('select_from_array')
        ->options(['active' => 'Active', 'inactive' => 'Inactive'])
        ->wrapper(['class' => 'col-md-6']);
    }

    /**
     * Define what happens when the Update operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-update
     * @return void
     */
    protected function setupUpdateOperation()
    {
        $this->setupCreateOperation();
    }
    protected function setupDeleteOperation(): void
    {
        CRUD::field('image')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'banners',
            ]);
    }
}
