<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests\GalleryRequest;
use Backpack\CRUD\app\Http\Controllers\CrudController;
use Backpack\CRUD\app\Library\CrudPanel\CrudPanelFacade as CRUD;

/**
 * Class GalleryCrudController
 * @package App\Http\Controllers\Admin
 * @property-read \Backpack\CRUD\app\Library\CrudPanel\CrudPanel $crud
 */
class GalleryCrudController extends CrudController
{
    use \Backpack\CRUD\app\Http\Controllers\Operations\ListOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\CreateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\UpdateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\DeleteOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\ShowOperation;

    /**
     * Configure the CrudPanel object. Apply settings to all operations.
     *
     * @return void
     */
    public function setup()
    {
        CRUD::setModel(\App\Models\Gallery::class);
        CRUD::setRoute(config('backpack.base.route_prefix') . '/gallery');
        CRUD::setEntityNameStrings('gallery', 'galleries');
    }

    /**
     * Define what happens when the List operation is loaded.
     *
     * @see  https://backpackforlaravel.com/docs/crud-operation-list-entries
     * @return void
     */
    protected function setupListOperation()
    {
        CRUD::setOperationSetting('lineButtonsAsDropdown', true);
        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();
        CRUD::column('title');
        CRUD::column('date');
        CRUD::column([
            'name' => 'image',
            'label' => 'image',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        CRUD::column([
            'name' => 'image_2',
            'label' => 'image_2',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        CRUD::column([
            'name' => 'image_3',
            'label' => 'image_3',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        CRUD::column([
            'name' => 'image_4',
            'label' => 'image$',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        CRUD::column([
            'name' => 'image_5',
            'label' => 'image_5',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        CRUD::column([
            'name' => 'image_6',
            'label' => 'image_6',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
    }

    /**
     * Define what happens when the Create operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-create
     * @return void
     */
    protected function setupCreateOperation()
    {
        CRUD::setValidation(GalleryRequest::class);
        CRUD::setFromDb(); // set fields from db columns.
        CRUD::field('title')->label('Title(EN)')->tab('Event Details')->wrapper(['class' => 'col-md-6 mt-2']);
        CRUD::field('title_arabic')->label('Title(AR)')->tab('Event Details')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field('date')->tab('Event Details')->wrapper(['class' => 'col-md-6 mt-2']);
        CRUD::field('order')->tab('Event Details')->wrapper(['class' => 'col-md-6 mt-2']);
        CRUD::field('status')
            ->type('select_from_array')
            ->options(['active' => 'Active', 'inactive' => 'Inactive'])
            ->tab('Event Details')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field([
            'name' => 'caption',
            'label' => 'Description / Caption(EN)',
            'type' => 'summernote',
        ])->tab('Event Details')->wrapper(['class' => 'col-md-12 mt-2']);

        CRUD::field([
            'name' => 'caption_arabic',
            'label' => 'Description / Caption (AR)',
            'type' => 'summernote',
        ])->tab('Event Details')->wrapper(['class' => 'col-md-12 mt-2']);

//        CRUD::field('text_content')->type('summernote');

        CRUD::field('image')->type('upload')
            ->label('Image')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ])->tab('Gallery')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field('image_2')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ])->tab('Gallery')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field('image_3')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ])->tab('Gallery')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field('image_4')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ])->tab('Gallery')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field('image_5')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ])->tab('Gallery')->wrapper(['class' => 'col-md-6 mt-2']);

        CRUD::field('image_6')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ])->tab('Gallery')->wrapper(['class' => 'col-md-6 mt-2']);
    }


    protected function setupShowOperation(): void
    {

        $this->autoSetupShowOperation();

        CRUD::field('image')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_2')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_3')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_4')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_5')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_6')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);
    }
    /**
     * Define what happens when the Update operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-update
     * @return void
     */
    protected function setupUpdateOperation()
    {
        $this->setupCreateOperation();
    }

    protected function setupDeleteOperation(): void
    {
        CRUD::field('image')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_2')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_3')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_4')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_5')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);

        CRUD::field('image_6')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'newsEvents',
            ]);
    }
}
