<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests\HomeSectionRequest;
use Backpack\CRUD\app\Http\Controllers\CrudController;
use Backpack\CRUD\app\Library\CrudPanel\CrudPanelFacade as CRUD;
use Backpack\CRUD\app\Library\Widget;

/**
 * Class HomeSectionCrudController
 * @package App\Http\Controllers\Admin
 * @property-read \Backpack\CRUD\app\Library\CrudPanel\CrudPanel $crud
 */
class HomeSectionCrudController extends CrudController
{
    use \Backpack\CRUD\app\Http\Controllers\Operations\ListOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\CreateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\UpdateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\DeleteOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\ShowOperation;

    /**
     * Configure the CrudPanel object. Apply settings to all operations.
     *
     * @return void
     */
    public function setup()
    {
        CRUD::setModel(\App\Models\HomeSection::class);
        CRUD::setRoute(config('backpack.base.route_prefix') . '/home-section');
        CRUD::setEntityNameStrings('home section', 'home sections');
    }

    /**
     * Define what happens when the List operation is loaded.
     *
     * @see  https://backpackforlaravel.com/docs/crud-operation-list-entries
     * @return void
     */
    protected function setupListOperation()
    {
        CRUD::setOperationSetting('lineButtonsAsDropdown', true);
        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();
        CRUD::column('home_section')->type('enum');
        CRUD::column('main_title');


    }

    /**
     * Define what happens when the Create operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-create
     * @return void
     */
    protected function setupCreateOperation()
    {
        Widget::add()->type('script')->content('assets/js/admin/forms/homeSection.js');

        CRUD::setValidation(HomeSectionRequest::class);
        CRUD::setFromDb();
        // set fields from db columns.

        CRUD::field([
            'name'  => 'home_section',
            'label' => 'Page Section',
            'type'  => 'enum',
            'enum_function' => 'readableText',

        ]);

        CRUD::field('top_title')->label('Top Title (EN)')->type('text')->wrapper(['class' => 'col-md-6']);
        CRUD::field('main_title')->label('Main Title (ER)')->type('text')->wrapper(['class' => 'col-md-6']);

        CRUD::field('top_title_arabic')->label('Top Title (AR)')->type('text')->wrapper(['class' => 'col-md-6']);
        CRUD::field('main_title_arabic')->label('Main Title (AR)')->type('text')->wrapper(['class' => 'col-md-6']);

        CRUD::field('about_image_1')
        ->label('Image (300x580)')

        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ])->wrapper(['class' => 'col-md-6']);

        CRUD::field('about_image_2')
        ->label('Image ( 280x280)')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ])->wrapper(['class' => 'col-md-6']);

        CRUD::field('about_image_3')
        ->label('Image ( 280x280)')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ])->wrapper(['class' => 'col-md-6']);

        CRUD::field('choose_image')
        ->label('Image ( 486x730)')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ])->wrapper(['class' => 'col-md-6']);

        CRUD::field('description')->label('Description (EN)')->type('summernote');
        CRUD::field('description_arabic')->label('Description (AR)')->type('summernote');


    }

    /**
     * Define what happens when the Update operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-update
     * @return void
     */
    protected function setupUpdateOperation()
    {
        $this->setupCreateOperation();
    }

    protected function setupDeleteOperation(): void
    {
        CRUD::field('about_image_1')

        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ]);

        CRUD::field('about_image_2')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ]);

        CRUD::field('about_image_3')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ]);

        CRUD::field('choose_image')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'home_section',
        ]);

    }
}
