<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests\MemberRequest;
use Backpack\CRUD\app\Http\Controllers\CrudController;
use Backpack\CRUD\app\Library\CrudPanel\CrudPanelFacade as CRUD;

/**
 * Class MemberCrudController
 * @package App\Http\Controllers\Admin
 * @property-read \Backpack\CRUD\app\Library\CrudPanel\CrudPanel $crud
 */
class MemberCrudController extends CrudController
{
    use \Backpack\CRUD\app\Http\Controllers\Operations\ListOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\CreateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\UpdateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\DeleteOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\ShowOperation;

    /**
     * Configure the CrudPanel object. Apply settings to all operations.
     *
     * @return void
     */
    public function setup()
    {
        CRUD::setModel(\App\Models\Member::class);
        CRUD::setRoute(config('backpack.base.route_prefix') . '/member');
        CRUD::setEntityNameStrings('member', 'members');
    }

    /**
     * Define what happens when the List operation is loaded.
     *
     * @see  https://backpackforlaravel.com/docs/crud-operation-list-entries
     * @return void
     */
    protected function setupListOperation()
    {
        CRUD::setOperationSetting('lineButtonsAsDropdown', true);

        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();

        $this->crud->addColumn([
            'name'=>'name',
            'label'=>'Name'
        ]);

        $this->crud->addColumn([
            'name' => 'image',
            'label' => 'image',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        $this->crud->addColumn('position');
        $this->crud->addColumn([
            'name' => 'email',
            'type' => 'email'
        ]);
    }

    /**
     * Define what happens when the Create operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-create
     * @return void
     */
    protected function setupCreateOperation()
    {
        CRUD::setValidation(MemberRequest::class);
        CRUD::setFromDb(); // set fields from db columns.

        CRUD::field('name')->label('Name')->wrapper(['class' => 'col-md-6'])->tab('Personal Details');

        CRUD::field('position')->wrapper(['class' => 'col-md-6'])->tab('Personal Details');
        CRUD::field('email')->type('email')->wrapper(['class' => 'col-md-6'])->tab('Personal Details');
        CRUD::field('contact')->type('number')->wrapper(['class' => 'col-md-6'])->tab('Personal Details');
        CRUD::field('image')->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'members',
        ])->wrapper(['class' => 'col-md-6'])->tab('Personal Details');
        CRUD::field('about')->type('summernote')->label('About')->tab('Personal Details');

        CRUD::field('order')->type('number')->wrapper(['class' => 'col-md-6'])->tab('Personal Details');
        CRUD::field('status')
            ->type('select_from_array')
            ->options(['active' => 'Active', 'inactive' => 'Inactive'])
            ->tab('Personal Details')->wrapper(['class' => 'col-md-6']);

      CRUD::field('facebook')->wrapper(['class' => 'col-md-6'])->tab('Social Links');
      CRUD::field('twitter')->wrapper(['class' => 'col-md-6'])->tab('Social Links');
      CRUD::field('instagram')->wrapper(['class' => 'col-md-6'])->tab('Social Links');
      CRUD::field('linkedin')->wrapper(['class' => 'col-md-6'])->tab('Social Links');
    }

    /**
     * Define what happens when the Update operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-update
     * @return void
     */
    protected function setupUpdateOperation()
    {
        $this->setupCreateOperation();
    }
    protected function setupDeleteOperation(): void
    {
        CRUD::field('image')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'members',
            ]);
    }
}
