<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests\PageRequest;
use Backpack\CRUD\app\Http\Controllers\CrudController;
use Backpack\CRUD\app\Library\CrudPanel\CrudPanelFacade as CRUD;

/**
 * Class PageCrudController
 * @package App\Http\Controllers\Admin
 * @property-read \Backpack\CRUD\app\Library\CrudPanel\CrudPanel $crud
 */
class PageCrudController extends CrudController
{
    use \Backpack\CRUD\app\Http\Controllers\Operations\ListOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\CreateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\UpdateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\DeleteOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\ShowOperation;

    /**
     * Configure the CrudPanel object. Apply settings to all operations.
     *
     * @return void
     */
    public function setup()
    {
        CRUD::setModel(\App\Models\Page::class);
        CRUD::setRoute(config('backpack.base.route_prefix') . '/page');
        CRUD::setEntityNameStrings('page', 'pages');
    }

    /**
     * Define what happens when the List operation is loaded.
     *
     * @see  https://backpackforlaravel.com/docs/crud-operation-list-entries
     * @return void
     */
    protected function setupListOperation()
    {
        CRUD::setOperationSetting('lineButtonsAsDropdown', true);
        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();

        CRUD::column('main_title');

    }

    /**
     * Define what happens when the Create operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-create
     * @return void
     */
    protected function setupCreateOperation()
    {
        CRUD::setValidation(PageRequest::class);
        CRUD::setFromDb(); // set fields from db columns.
        CRUD::field('template')
        ->type('select_from_array')
        ->options(['about' => 'About Page'])
        ->wrapper(['class' => 'col-md-6']);

        CRUD::field('top_title')->label('Top Title (EN)')->type('text')->wrapper(['class' => 'col-md-6']);
        CRUD::field('main_title')->label('Main Title (EN)')->type('text')->wrapper(['class' => 'col-md-6']);

        CRUD::field('top_title_arabic')->label('Top Title (AR)')->type('text')->wrapper(['class' => 'col-md-6']);
        CRUD::field('main_title_arabic')->label('Main Title (AR)')->type('text')->wrapper(['class' => 'col-md-6']);

        CRUD::field('image_1')
        ->label('Main Image (694x463)')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'about',
        ])->wrapper(['class' => 'col-md-6']);

        CRUD::field('image_2')
        ->label('Sub Image (582x387)')
        ->type('upload')
        ->withFiles([
            'disk' => 'public',
            'path' => 'about',
        ])->wrapper(['class' => 'col-md-6']);
        CRUD::field('content')->type('summernote')->label('Content(EN)');
        CRUD::field('content_arabic')->type('summernote')->label('Content(AR)');

    }

    /**
     * Define what happens when the Update operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-update
     * @return void
     */
    protected function setupUpdateOperation()
    {
        $this->setupCreateOperation();
    }
}
