<?php

namespace App\Http\Controllers\Admin;

use App\Http\Requests\ServiceRequest;
use Backpack\CRUD\app\Http\Controllers\CrudController;
use Backpack\CRUD\app\Library\CrudPanel\CrudPanelFacade as CRUD;

/**
 * Class ServiceCrudController
 * @package App\Http\Controllers\Admin
 * @property-read \Backpack\CRUD\app\Library\CrudPanel\CrudPanel $crud
 */
class ServiceCrudController extends CrudController
{
    use \Backpack\CRUD\app\Http\Controllers\Operations\ListOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\CreateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\UpdateOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\DeleteOperation;
    use \Backpack\CRUD\app\Http\Controllers\Operations\ShowOperation;

    /**
     * Configure the CrudPanel object. Apply settings to all operations.
     *
     * @return void
     */
    public function setup()
    {
        CRUD::setModel(\App\Models\Service::class);
        CRUD::setRoute(config('backpack.base.route_prefix') . '/service');
        CRUD::setEntityNameStrings('service', 'services');
    }

    /**
     * Define what happens when the List operation is loaded.
     *
     * @see  https://backpackforlaravel.com/docs/crud-operation-list-entries
     * @return void
     */
    protected function setupListOperation()
    {
        CRUD::setOperationSetting('lineButtonsAsDropdown', true);
        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();
        $this->crud->addColumn([
            'name'      => 'row_number',
            'type'      => 'row_number',
            'label'     => '#',
            'orderable' => false,
        ])->makeFirstColumn();

        $this->crud->addColumn([
            'name'=>'name',
            'label'=>'Name'
        ]);

        $this->crud->addColumn([
            'name' => 'image',
            'label' => 'image',
            'type' => 'image',
            'disk' => 'public',
            'width' => '85px',
            'height' => '85px'
        ]);
        $this->crud->addColumn('status');

    }

    /**
     * Define what happens when the Create operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-create
     * @return void
     */
    protected function setupCreateOperation()
    {
        CRUD::setValidation(ServiceRequest::class);
        CRUD::setFromDb(); // set fields from db columns.

        CRUD::field('name')->label('Service Name (EN)')->type('text')->wrapper(['class' => 'col-md-6']);
        CRUD::field('name_arabic')->label('Service Name (AR)')->type('text')->wrapper(['class' => 'col-md-6']);

        CRUD::addField([
            'name' => 'slug',
            'label' => 'slug',
            'type' => 'text',
            'attributes' => [
               'readonly' => 'readonly',
             ],
             'wrapper' => ['class' => 'col-md-6'],
            ]);

        CRUD::field('image')->type('upload')
        ->label('Service Image (width 610 x height 400)')
        ->withFiles([
            'disk' => 'public',
            'path' => 'service',
        ])->wrapper(['class' => 'col-md-6']);
        CRUD::field('short_desc')->type('summernote')->label('Short Description (EN)');
        CRUD::field('long_desc')->type('summernote')->label('Long Description (EN)');

        CRUD::field('short_desc_arabic')->type('summernote')->label('Short Description(AR)');
        CRUD::field('long_desc_arabic')->type('summernote')->label('Long Description(AR');

        CRUD::field('order')->type('number')->wrapper(['class' => 'col-md-6']);
        CRUD::field('is_homepage')->type('checkbox')->wrapper(['class' => 'col-md-6']);

        CRUD::field('status')
            ->type('select_from_array')
            ->options(['active' => 'Active', 'inactive' => 'Inactive'])
            ->wrapper(['class' => 'col-md-6']);
    }

    /**
     * Define what happens when the Update operation is loaded.
     *
     * @see https://backpackforlaravel.com/docs/crud-operation-update
     * @return void
     */
    protected function setupUpdateOperation()
    {
        $this->setupCreateOperation();
    }

    protected function setupDeleteOperation(): void
    {
        CRUD::field('image')->type('upload')
            ->withFiles([
                'disk' => 'public',
                'path' => 'service',
            ]);
    }
}
