<?php

namespace App\Http\Controllers;
use App\Enums\PageEnums;
use App\Http\Controllers\Controller;
use App\Jobs\SendContactFormEmail;
use App\Jobs\SendServiceRequestFormEmail;
use App\Models\FormSubmit;
use App\Services\BannerService;
use App\Services\ClientService;
use App\Services\FaqService;
use App\Services\GalleryService;
use App\Services\HomeSectionService;
use App\Services\MemberService;
use App\Services\PageService;
use App\Services\ServiceService;
use App\Services\TestimonyService;
use Illuminate\Contracts\View\View;
use Illuminate\Http\Request;

class PageController extends Controller
{
    /**
     * @var ClientService $clientService
     */
    private ClientService $clientService;

    /**
     * @var MemberService $memberService
     */
    private MemberService $memberService;

    /**
     * @var BannerService $bannerService
     */
    private BannerService $bannerService;

    /**
     * @var ServiceService $serviceService
     */
    private ServiceService $serviceService;

    /**
     * @var GalleryService $galleryService
     */
    private GalleryService $galleryService;

    /**
     * @var TestimonyService $testimonyService
     */
    private TestimonyService $testimonyService;


    /**
     * @var HomeSectionService $homeSectionService
     */
    private HomeSectionService $homeSectionService;


     /**
     * @var FaqService $faqService
     */
    private FaqService $faqService;


     /**
     * @var PageService $pageService
     */
    private PageService $pageService;

    public function __construct(
        ClientService $clientService,
        MemberService $memberService,
        BannerService $bannerService,
        ServiceService $serviceService,
        GalleryService $galleryService,
        TestimonyService $testimonyService,
        HomeSectionService $homeSectionService,
        FaqService $faqService,
        PageService $pageService,


    ) {
        $this->clientService = $clientService;
        $this->memberService = $memberService;
        $this->bannerService = $bannerService;
        $this->serviceService = $serviceService;
        $this->galleryService = $galleryService;
        $this->testimonyService = $testimonyService;
        $this->homeSectionService = $homeSectionService;
        $this->faqService = $faqService;
        $this->pageService = $pageService;

    }


    public function index(string $slug = 'home'): View
    {

        $data = [
            'menus' => $this->serviceService->getAllServiceNames()
        ];
        switch ($slug) {
            case PageEnums::HOME->value:
                $data['banners'] = $this->bannerService->getAllNameSorted();
                $data['clients'] = $this->clientService->all();
                $data['services'] = $this->serviceService->getAllHomePageServices();
                $data['members'] = $this->memberService->all();
                $data['testimonials'] = $this->testimonyService->all();
                $data['home_section'] = $this->homeSectionService->all();
                $view = view('index', $data);
                break;

            case PageEnums::GALLERY->value:
                $orderedGalleries = $this->galleryService->getOrderedGallery();
                $unOrderedGalleries = $this->galleryService->getUnorderedGallery();
                $galleries = collect($orderedGalleries)->merge($unOrderedGalleries);
                $data['galleries'] = $galleries->toArray();
                $view = view('gallery', $data);
                break;

            case PageEnums::FAQS->value:
                $data['faqs'] = $this->faqService->all();

                $view = view('faq', $data);
                break;

                case PageEnums::ABOUT->value:
                    $data['about'] = $this->pageService->firstWhere(['template' => 'about']);

                    $view = view('about-us', $data);
                    break;

                    case PageEnums::CONTACT->value:
                        $view = view('contact-us', $data);
                        break;
            default:
                $data['service_detail'] = $this->serviceService->firstWhere(['slug' => $slug]);
                if ($data['service_detail']) {
                    return view('service-detail', $data);
                } else {
                    abort(404);
                }
        }


        return $view;
    }

    public function submitContactForm(Request $request)
    {

        $email = "israr@sayg.bh";
        // Validate the form data
        $validatedData = $request->validate([
            'fname' => 'required',
            'lname' => 'required',
            'phone' => 'required',
            'email' => 'required|email',
            'message' => 'required',
        ]);

        $form_data = new FormSubmit();
        $form_data->type = 'contact';
        $form_data->form_data = json_encode($validatedData);
        $form_data->save();

        $db_form_data = FormSubmit::where('id', $form_data->id)->first();
        $form_json_data = json_decode($db_form_data->form_data);
        SendContactFormEmail::dispatch($form_json_data, $email);
        // Send the email

        return redirect()->back()->with('success', 'Thank you for your message!');
    }

    public function submitServiceRequestForm(Request $request)
    {

        $email = "israr@sayg.bh";
        // Validate the form data

        $validatedData = $request->validate([
            'name' => 'required',
            'phone' => 'required',
            'email' => 'required|email',
            'service_type' => 'required',
        ]);

        $form_data = new FormSubmit();
        $form_data->type = 'service_request';
        $form_data->form_data = json_encode($validatedData);
        $form_data->save();

        $db_form_data = FormSubmit::where('id', $form_data->id)->first();
        $form_json_data = json_decode($db_form_data->form_data);
        SendServiceRequestFormEmail::dispatch($form_json_data, $email);
        // Send the email

        return redirect()->back()->with('success', 'Thank you for your message!');
    }

    public function languageSwitch(Request $request)
    {
        $language = $request->input('language');

        session(['language'=>$language]);
        return redirect()->back()->with(['language_switched'=>$language]);
    }
}
