<?php

declare(strict_types=1);

namespace App\Interfaces\Services;

use Illuminate\Contracts\Pagination\LengthAwarePaginator;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Database\Eloquent\Model;

interface IBaseService
{
    /**
     * Create a new record
     *
     * @param array $data
     * @return Model
     */
    public function create(array $data): Model;

    /**
     * Find a record
     *
     * @param int $id
     * @param array $relations
     * @return Model|null
     */
    public function findOrFail(int $id, array $relations = []): ?Model;

    /**
     * Update a record
     *
     * @param int $id
     * @param array $data
     * @return Model|null
     */
    public function update(int $id, array $data): ?Model;

    /**
     * Delete record
     *
     * @param int $id
     * @return bool
     */
    public function delete(int $id): bool;

    /**
     * All records
     *
     * @param array $relations
     * @return Collection
     */
    public function all(array $relations = []): Collection;

    /**
     * Get all records in descending order
     *
     * @param array $relations
     * @return Collection
     */
    public function latest(array $relations = []): Collection;

    /**
     * Get First record meeting the criteria
     *
     * @param array $conditions
     * @param array $relations
     * @return Model|null
     */
    public function firstWhere(array $conditions, array $relations = []): ?Model;

    /**
     * Get all record meeting the criteria
     *
     * @param array $conditions
     * @param array $relations
     * @return Collection
     */
    public function allWhere(array $conditions, array $relations = []): Collection;

    /**
     * Get All Records paginated
     *
     * @param int $paginate
     * @param array $conditions
     * @param array $relations
     * @return LengthAwarePaginator
     */
    public function allPaginated(int $paginate, array $conditions, array $relations = []): LengthAwarePaginator;
}
